#include "UI.h"

const std::string UI::NORMAL_WINDOW = "Normal";
const std::string UI::DEBUG_WINDOW = "Debug";

UI::UI(std::shared_ptr<int> lastKey) {
	this->lastKey = lastKey;
}

void UI::render() {
	if (state < frames.size() -1) {
		frames.resize(state + 1);
		lastDebugFrame = debugFrame;
		debugFrame = std::min(state, debugFrame);
	}

	if (lastDebugFrame != 0 && lastDebugFrame <= frames.size()-1) {
		debugFrame = lastDebugFrame;
		lastDebugFrame = 0;
	}
	state = 0;
	cv::imshow(UI::NORMAL_WINDOW, frame);
	if (debug) {
		cv::imshow(UI::DEBUG_WINDOW, frames[debugFrame]);
	}

	if (*lastKey == 100) {
		debug = !debug;
		if (debug == true) {
			cv::imshow(UI::DEBUG_WINDOW, frames[debugFrame]);
			for (unsigned i = 0; i < UIListeners.size(); i++) {
				UIListeners[i]->componentSetup();
			}
		} else {
			cv::destroyWindow(UI::DEBUG_WINDOW);
		}
	}

	if (debug) {
		if (*lastKey == 110) {
			nextDebugFrame();
		}
	}
}

cv::Mat* UI::nextFrame() {
	state++;
	if (state + 1 > frames.size()) {
		frames.push_back(cv::Mat {});

	}
	return &(frames[state]);
}

cv::Mat* UI::currentFrame(int offset) {
	return &(frames[state + offset]);
}

void UI::nextDebugFrame() {
	debugFrame++;
	if (debugFrame > frames.size() - 1) {
		debugFrame = 0;
	}
}

void UI::setOriginalFrame(cv::Mat frame) {
	width = frame.cols;
	height = frame.rows;
	frames[0] = frame;
	frames[0].copyTo(UI::frame);
	frames[0].copyTo(originalFrame);
}

cv::Mat* UI::drawnFrame() {
	return &frame;
}

cv::Mat UI::getOriginalFrame() const {
	return originalFrame;
}

int UI::getWidth() const {
	return width;
}

int UI::getHeight() const {
	return height;
}

UI::~UI() {
}
